%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Filename:    PS2000_IC_Generic_Driver_GetBlock.m
%
% Copyright:   Pico Technology Limited 2013
%
% Author:      HSM
%
% Description:
%   This is a MATLAB script that demonstrates how to use the
%   PicoScope 2000 series Instrument Control Toobox driver to collect
%   a block of samples.
%
%   A part of this script was generated using the Test and Measurement
%   Tool.
%
% Examples:
%    Collect a block of samples immediately.
%
%	To run this application:
%		
%   Click 'Run' in the MATLAB Editor or see the generated comment block
%   below.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%PS2000_IC_GENERIC_DRIVER_GETBLOCK Code for communicating with an instrument. 
%  
%   This is the machine generated representation of an instrument control 
%   session using a device object. The instrument control session comprises  
%   all the steps you are likely to take when communicating with your  
%   instrument. These steps are:
%       
%       1. Create a device object   
%       2. Connect to the instrument 
%       3. Configure properties 
%       4. Invoke functions 
%       5. Disconnect from the instrument 
%  
%   To run the instrument control session, type the name of the file,
%   PS2000_IC_Generic_Driver_GetBlock, at the MATLAB command prompt.
% 
%   The file, PS2000_IC_GENERIC_DRIVER_GETBLOCK.M must be on your MATLAB PATH. For additional information
%   on setting your MATLAB PATH, type 'help addpath' at the MATLAB command
%   prompt.
%
%   Example:
%       PS2000_IC_Generic_Driver_GetBlock;
%
%   See also ICDEVICE.
%

%   Creation time: 04-Jan-2013 15:28:07 

%% CLEAR WORKSPACE

clear all;
clc;

%% LOAD CONFIGURATION INFORMATION

PS2000Config;

%% DEVICE CONNECTION

% Create a device object. 
ps2000DeviceObj = icdevice('picotech_ps2000_generic.mdd');

% Connect device object to hardware.
connect(ps2000DeviceObj);

%% DATA COLLECTION

disp('Collecting block of data...');

% Execute device object function(s).
[bufferTimes, bufferChA, bufferChB, numDataValues, timeIndisposedMs] = invoke(ps2000DeviceObj, 'getBlockData');

disp('Data collection complete.');

%% PROCESS DATA

disp('Processing data for plot...')

% Obtain channel settings
ps2000ChannelSettings = j2m(get(ps2000DeviceObj, 'channelSettings'));

% Create arrays to store milliVolt data in
channelAValuesMV = zeros(numDataValues, 1);
channelBValuesMV = zeros(numDataValues, 1);

% Obtain channel ranges (+/- mV)
channelAVoltageRangeMV = PicoConstants.SCOPE_INPUT_RANGES(ps2000ChannelSettings.channelA.range + 1);
channelBVoltageRangeMV = PicoConstants.SCOPE_INPUT_RANGES(ps2000ChannelSettings.channelB.range + 1);

% Convert data to milliVolts
for i = 1:numDataValues
   
    channelAValuesMV(i, 1) = adc2mv(bufferChA(i, 1), channelAVoltageRangeMV, get(ps2000DeviceObj, 'maxValue')); 
    channelBValuesMV(i, 1) = adc2mv(bufferChB(i, 1), channelBVoltageRangeMV, get(ps2000DeviceObj, 'maxValue'));
    
end

% Find the time units used by the driver
timesUnits = adcunits(get(ps2000DeviceObj, 'timeUnits'));

% Append to string
time_label = strcat('Time (', timesUnits, ')');

% Plot

figure;
plot(bufferTimes, channelAValuesMV, bufferTimes, channelBValuesMV);
title('Plot of Voltage vs. Time');
xlabel(time_label);
ylabel('Voltage (mv)');
legend('Channel A', 'Channel B');

%% DISCONNECT

% Disconnect device object from hardware.
disconnect(ps2000DeviceObj);
