%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Filename:    PS2000_IC_Generic_Driver_SigGen_BuiltIn.m
%
% Copyright:   Pico Technology Limited 2013
%
% Author:      HSM
%
% Description:
%   This is a MATLAB script that demonstrates how to use the
%   PicoScope 2000 series Instrument Control Toobox driver to generate
%   signals using the function generator (applies to PicoScope 2203, 2204
%   and 2205 ONLY).
%
%   A part of this script was generated using the Test and Measurement
%   Tool.
%
% Examples:
%   Generate a waveform of constant frequency with/without offset.
%   Generate a waveform and sweep between the specified start/stop frequency.
%   Turn off the function generator.
%
%	To run this application:
%		
%   Click 'Run' in the MATLAB Editor or see the generated comment block
%   below.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%PS2000_IC_GENERIC_DRIVER_SIGGEN_BUILTIN Code for communicating with an instrument. 
%  
%   This is the machine generated representation of an instrument control 
%   session using a device object. The instrument control session comprises  
%   all the steps you are likely to take when communicating with your  
%   instrument. These steps are:
%       
%       1. Create a device object   
%       2. Connect to the instrument 
%       3. Configure properties 
%       4. Invoke functions 
%       5. Disconnect from the instrument 
%  
%   To run the instrument control session, type the name of the file,
%   PS2000_IC_Generic_Driver_SigGen_BuiltIn, at the MATLAB command prompt.
% 
%   The file, PS2000_IC_GENERIC_DRIVER_SIGGEN_BUILTIN.M must be on your MATLAB PATH. 
%   For additional information on setting your MATLAB PATH, type 'help addpath' 
%   at the MATLAB command prompt.
%
%   Example:
%       PS2000_IC_Generic_Driver_SigGen_BuiltIn;
%
%   See also ICDEVICE.
%

%   Creation time: 18-Jan-2013 15:08:14 

%% CLEAR WORKSPACE

clear all;
clc;

%% LOAD CONFIGURATION INFORMATION

PS2000Config;

%% DEVICE CONNECTION

% Create a device object. 
ps2000DeviceObj = icdevice('picotech_ps2000_generic.mdd');

% Connect device object to hardware.
connect(ps2000DeviceObj);

%% SIGNAL GENERATOR

% Execute device object function(s).

% Use the evalin command in the input arguments line in the Test and
% Measurement Tool using the 'base' workspace to load in variables from the
% MATLAB environment
% When writing a script, the evalin is not required

[sigGenSimpleStatus] = invoke(ps2000DeviceObj, 'setSigGenBuiltInSimple', ...
    evalin('base', 'sigGen.offsetVoltage'), evalin('base', 'sigGen.pkToPk'), ...
    evalin('base', 'ps2000Enuminfo.enPS2000WaveType.PS2000_SINE'), 500);

% Change to square wave
[sigGenSimpleStatus1] = invoke(ps2000DeviceObj, 'setSigGenBuiltInSimple', 0, 2000, 1, 1000);

% Output a triangle waveform and sweep up from start to stop frequency
[sigGenBuiltInStatus] = invoke(ps2000DeviceObj, 'ps2000SetSigGenBuiltIn', 250, 3000, ...
    ps2000Enuminfo.enPS2000WaveType.PS2000_TRIANGLE, sigGen.builtIn.startFrequency, ...
    sigGen.builtIn.stopFrequency, sigGen.builtIn.increment, ...
    sigGen.builtIn.dwellTime, sigGen.sweepType, sigGen.sweeps);

% Output a sine wave and sweep up and down from start to stop frequency in 
% 500Hz steps 5 times
[sigGenBuiltInStatus1] = invoke(ps2000DeviceObj, 'ps2000SetSigGenBuiltIn', 0, 2000, 0, 500, 5000, 500, 2, 2, 5);

% Turn off the signal generator
[sigGenOffStatus] = invoke(ps2000DeviceObj, 'setSigGenOff');

%% DISCONNECT

% Disconnect device object from hardware.
disconnect(ps2000DeviceObj);